==> haskell-system-filepath-0.4.14-119-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-system-filepath.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 system-filepath
version:              0.4.14
visibility:           public
id:                   system-filepath-0.4.14-5NTtLhNgj3DA8uPsvILAmh
key:                  system-filepath-0.4.14-5NTtLhNgj3DA8uPsvILAmh
license:              MIT
copyright:            John Millikin 2010-2012
maintainer:           FP Complete <michael@fpcomplete.com>
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://github.com/fpco/haskell-filesystem
synopsis:
    High-level, byte-based file and directory path manipulations (deprecated)

description:
    Please see: https://plus.google.com/+MichaelSnoyman/posts/Ft5hnPqpgEx

category:             System
abi:                  106622e686364e2723143211568ab6b7
exposed:              True
exposed-modules:
    Filesystem.Path Filesystem.Path.CurrentOS Filesystem.Path.Rules

hidden-modules:       Filesystem.Path.Internal
import-dirs:          /usr/lib/ghc-8.10.4/site-local/system-filepath-0.4.14
library-dirs:         /usr/lib/ghc-8.10.4/site-local/system-filepath-0.4.14
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/system-filepath-0.4.14
hs-libraries:         HSsystem-filepath-0.4.14-5NTtLhNgj3DA8uPsvILAmh
depends:
    base-4.14.1.0 bytestring-0.10.12.0 deepseq-1.4.4.0 text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-system-filepath/html/system-filepath.haddock

haddock-html:         /usr/share/doc/haskell-system-filepath/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-system-filepath-0.4.14-120-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-system-filepath.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 system-filepath
version:              0.4.14
visibility:           public
id:                   system-filepath-0.4.14-DoOTC7rp9j1IAoHHCXQjzz
key:                  system-filepath-0.4.14-DoOTC7rp9j1IAoHHCXQjzz
license:              MIT
copyright:            John Millikin 2010-2012
maintainer:           FP Complete <michael@fpcomplete.com>
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://github.com/fpco/haskell-filesystem
synopsis:
    High-level, byte-based file and directory path manipulations (deprecated)

description:
    Please see: https://plus.google.com/+MichaelSnoyman/posts/Ft5hnPqpgEx

category:             System
abi:                  5e19b3835210167ffb8d6ee900432f27
exposed:              True
exposed-modules:
    Filesystem.Path Filesystem.Path.CurrentOS Filesystem.Path.Rules

hidden-modules:       Filesystem.Path.Internal
import-dirs:          /usr/lib/ghc-8.10.4/site-local/system-filepath-0.4.14
library-dirs:         /usr/lib/ghc-8.10.4/site-local/system-filepath-0.4.14
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/system-filepath-0.4.14
hs-libraries:         HSsystem-filepath-0.4.14-DoOTC7rp9j1IAoHHCXQjzz
depends:
    base-4.14.1.0 bytestring-0.10.12.0 deepseq-1.4.4.0 text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-system-filepath/html/system-filepath.haddock

haddock-html:         /usr/share/doc/haskell-system-filepath/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
